==> jc-1.4.0.tar.gz: java/nio/DirectByteBufferImpl__24ReadWrite.h <==
// final class java.nio.DirectByteBufferImpl$ReadWrite

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class acc48c6bb960328b java_nio_DirectByteBufferImpl
// @dep_class 3aa36747eda26759 java_nio_DirectByteBufferImpl__24ReadWrite

// header file dependencies
// @dep_header java_nio_DirectByteBufferImpl

#include "java/nio/DirectByteBufferImpl.h"

#ifndef _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_
#define _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$object;

typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype;

// Constructors
extern void _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *, jint);
extern void _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$_init$1316da41ff5f3d11(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *, struct _jc_java_lang_Object$object *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint);

// Virtual methods
extern jboolean _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *);

// Virtual method descriptors
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method_info$isReadOnly$c9d2a7ec56d3b05a;

// Virtual methods structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods {
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *);
};

// Vtable
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_DirectByteBufferImpl$vmethods	java_nio_DirectByteBufferImpl;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods	java_nio_DirectByteBufferImpl__24ReadWrite;
};

// Vtype
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype {
	_jc_type			type;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs {
    _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs	java_nio_DirectByteBufferImpl__24ReadWrite;
    _jc_java_nio_DirectByteBufferImpl$sub_refs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_DirectByteBufferImpl$sub_nonrefs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs	java_nio_DirectByteBufferImpl__24ReadWrite;
};

// Object instance structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object {
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype	*vtype;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype _jc_java_nio_DirectByteBufferImpl__24ReadWrite$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_DirectByteBufferImpl__24ReadWrite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_DirectByteBufferImpl__24ReadWrite$class_object;

#endif	/* _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_ */

==> jc-1.4.6.tar.gz: java/nio/DirectByteBufferImpl__24ReadWrite.h <==
// final class java.nio.DirectByteBufferImpl$ReadWrite

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9a9842bb79e9de6a java_nio_Buffer
// @dep_class c56860d6af73feea java_nio_ByteBuffer
// @dep_class acc48c6bb960328b java_nio_DirectByteBufferImpl
// @dep_class 3aa36747eda26759 java_nio_DirectByteBufferImpl__24ReadWrite

// header file dependencies
// @dep_header java_nio_DirectByteBufferImpl

#include "java/nio/DirectByteBufferImpl.h"

#ifndef _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_
#define _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_

// Forward structure declarations
struct _jc_gnu_classpath_RawData$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs;
typedef struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$object;

typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable;
typedef const struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype;

// Constructors
extern void _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$_init$1316da41ff5f3d11(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *, struct _jc_java_lang_Object$object *, struct _jc_gnu_classpath_RawData$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method$isReadOnly$c9d2a7ec56d3b05a(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_nio_DirectByteBufferImpl__24ReadWrite$method_info$isReadOnly$c9d2a7ec56d3b05a;

// Virtual methods structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods {
	jboolean	(*isReadOnly$c9d2a7ec56d3b05a)(_jc_env *, struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_Buffer$vmethods	java_nio_Buffer;
	_jc_java_nio_ByteBuffer$vmethods	java_nio_ByteBuffer;
	_jc_java_nio_DirectByteBufferImpl$vmethods	java_nio_DirectByteBufferImpl;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vmethods	java_nio_DirectByteBufferImpl__24ReadWrite;
};

// Vtype
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype {
	_jc_type			type;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs {
    _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_refs	java_nio_DirectByteBufferImpl__24ReadWrite;
    _jc_java_nio_DirectByteBufferImpl$sub_refs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_ByteBuffer$sub_refs	java_nio_ByteBuffer;
    _jc_java_nio_Buffer$sub_refs	java_nio_Buffer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_Buffer$sub_nonrefs	java_nio_Buffer;
    _jc_java_nio_ByteBuffer$sub_nonrefs	java_nio_ByteBuffer;
    _jc_java_nio_DirectByteBufferImpl$sub_nonrefs	java_nio_DirectByteBufferImpl;
    _jc_java_nio_DirectByteBufferImpl__24ReadWrite$sub_nonrefs	java_nio_DirectByteBufferImpl__24ReadWrite;
};

// Object instance structure
struct _jc_java_nio_DirectByteBufferImpl__24ReadWrite$object {
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype	*vtype;
	_jc_java_nio_DirectByteBufferImpl__24ReadWrite$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_DirectByteBufferImpl__24ReadWrite$vtype _jc_java_nio_DirectByteBufferImpl__24ReadWrite$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_DirectByteBufferImpl__24ReadWrite, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_DirectByteBufferImpl__24ReadWrite$class_object;

#endif	/* _JC_java_nio_DirectByteBufferImpl__24ReadWrite_H_ */
